Enum NativeMintWrappingStrategy
pub enum NativeMintWrappingStrategy {
Keypair,
Seed,
Ata,
None,
}Expand description
Defines the strategy for handling SOL wrapping in a transaction.
Variants
Keypair
Creates an auxiliary token account using a keypair. Optionally adds funds to the account. Closes it at the end of the transaction.
Seed
Functions similarly to Keypair, but uses a seed account instead.
Ata
Treats the native balance and associated token account (ATA) for NATIVE_MINT as one.
Will create the ATA if it doesn’t exist.
Optionally adds funds to the account.
Closes it at the end of the transaction if it did not exist before.
None
Uses or creates the ATA without performing any SOL wrapping or unwrapping.