Struct ClosePositionConfig
pub struct ClosePositionConfig {
pub slippage_tolerance_bps: Option<u16>,
pub authority: Option<Address>,
pub whirlpool_deployment: Option<WhirlpoolDeployment>,
}Fields
slippage_tolerance_bps: Option<u16>An optional slippage tolerance in basis points. Defaults to the global slippage tolerance if not provided.
An optional public key of the account authorizing the transaction. Defaults to the global funder if not provided.
whirlpool_deployment: Option<WhirlpoolDeployment>The Whirlpool program and config account to target.
Uses WhirlpoolDeployment::default when None.