Struct CreateConcentratedLiquidityPoolConfig
pub struct CreateConcentratedLiquidityPoolConfig {
pub initial_price: Option<f64>,
pub funder: Option<Address>,
pub whirlpool_deployment: Option<WhirlpoolDeployment>,
}Fields
initial_price: Option<f64>An optional initial price of token A in terms of token B. Defaults to 1.0 if not provided.
funder: Option<Address>An optional public key of the account funding the initialization process. Defaults to the global funder if not provided.
whirlpool_deployment: Option<WhirlpoolDeployment>The Whirlpool program and config account to target.
Uses WhirlpoolDeployment::default when None.